@@ -16,12 +16,15 @@ use Composer\Installer\InstallationManager;
 use Composer\DependencyResolver\Operation\InstallOperation;
 use Composer\DependencyResolver\Operation\UpdateOperation;
 use Composer\DependencyResolver\Operation\UninstallOperation;
+use PHPUnit\Framework\TestCase;
 
-class InstallationManagerTest extends \PHPUnit_Framework_TestCase
+class InstallationManagerTest extends TestCase
 {
+    protected $repository;
+
     public function setUp()
     {
-        $this->repository = $this->getMock('Composer\Repository\InstalledRepositoryInterface');
+        $this->repository = $this->getMockBuilder('Composer\Repository\InstalledRepositoryInterface')->getMock();
     }
 
     public function testAddGetInstaller()
@@ -83,7 +86,8 @@ class InstallationManagerTest extends \PHPUnit_Framework_TestCase
         $installOperation = new InstallOperation($this->createPackageMock());
         $removeOperation = new UninstallOperation($this->createPackageMock());
         $updateOperation = new UpdateOperation(
-            $this->createPackageMock(), $this->createPackageMock()
+            $this->createPackageMock(),
+            $this->createPackageMock()
         );
 
         $manager
