@@ -13,13 +13,14 @@
 namespace Composer\Test\Util;
 
 use Composer\Util\Platform;
+use PHPUnit\Framework\TestCase;
 
 /**
  * PlatformTest
  *
  * @author Niels Keurentjes <niels.keurentjes@omines.com>
  */
-class PlatformTest extends \PHPUnit_Framework_TestCase
+class PlatformTest extends TestCase
 {
     public function testExpandPath()
     {
@@ -28,7 +29,7 @@ class PlatformTest extends \PHPUnit_Framework_TestCase
         $this->assertEquals('/home/test/myPath', Platform::expandPath('$TESTENV/myPath'));
         $this->assertEquals((getenv('HOME') ?: getenv('USERPROFILE')) . '/test', Platform::expandPath('~/test'));
     }
-    
+
     public function testIsWindows()
     {
         // Compare 2 common tests for Windows to the built-in Windows test
